"""
Run these tests once a patch to deployed to an Antelope server to validate deployment
"""
import requests
import os
from urllib.parse import urljoin, urlencode
from http import HTTPStatus
from xml.etree import ElementTree as ET
from .util import load_server

WADL_ENDPOINT = 'application.wadl'
VERSION_ENDPOINT = 'version'


def test_version(server):
  api = load_server(server, 'station/')
  _url = urljoin(api, VERSION_ENDPOINT)
  resp = requests.get(_url)
  assert resp.status_code == HTTPStatus.OK

def test_wadl(server):
  api = load_server(server, 'station/')
  _url = urljoin(api, WADL_ENDPOINT)
  resp = requests.get(_url)
  assert resp.status_code == HTTPStatus.OK


def test_query_missing_req_param(server):
    api = load_server(server, 'station/')
    _url = api + 'query?mindepth=1'
    resp = requests.get(_url)
    assert resp.status_code == HTTPStatus.BAD_REQUEST

def test_query_sunnyday(server):
    api = load_server(server, 'station/')
    _url = api + 'query?level=station&starttime=2010-01-01%2000%3A00%3A00&network=AZ.%2A&station=.%2A&'\
                 'channel=.%2A&location=.%2A&minlatitude=-90&maxlatitude=90&minlongitude=-180&'\
                 'maxlongitude=180&nodata=204'
    resp = requests.get(_url)
    assert resp.status_code == HTTPStatus.OK
    content = ET.fromstring(resp.content.decode('utf-8'))
    assert 'FDSNStationXML' in format(content)

def test_query_204(server):
    api = load_server(server, 'station/')
    _url = api + 'query?level=station&starttime=2020-01-01%2000%3A00%3A00&network=AZ.%2A&station=.%2A&'\
                 'channel=.%2A&location=.%2A&minlatitude=-90&maxlatitude=90&minlongitude=-180&'\
                 'maxlongitude=180&nodata=204'
    print(_url)
    resp = requests.get(_url)
    assert resp.status_code == HTTPStatus.NO_CONTENT

def test_query_404(server):
    api = load_server(server, 'station/')
    _url = api + 'query?level=station&starttime=2020-01-01%2000%3A00%3A00&network=AZ.%2A&station=.%2A&'\
                 'channel=.%2A&location=.%2A&minlatitude=-90&maxlatitude=90&minlongitude=-180&'\
                 'maxlongitude=180&nodata=404'
    resp = requests.get(_url)
    assert resp.status_code == HTTPStatus.NOT_FOUND

def test_200_check_content(server):
    api = load_server(server, 'station/')
    _url = api + 'query?level=station&starttime=2010-01-01%2000%3A00%3A00&network=.%2A' \
                 '&station=WRDG.%2A&channel=.%2A&location=.%2A&minlatitude=-90&maxlatitude=90&' \
                 'minlongitude=-180&maxlongitude=180&nodata=404'
    print(_url)
    resp = requests.get(_url)
    cur_dir = os.path.dirname(__file__)
    # TODO: xml content in station_wrdg.xml will differ on <Created> timestamp info compared
    # to data returned by API. Need to ignore differing timestamps. For now just check for 
    # station WRDG being present in returned text.
    with open(os.path.join(cur_dir, os.pardir, 'test_data', 'station_wrdg.xml')) as f:
        assert 'WRDG' in resp.text
