import os
import re
import tempfile
import unittest
import xmltodict
import collections
from lxml import etree
from xml.etree import ElementTree as ET

from webservice_fdsn.app.core.event_exporter import event2qml
from webservice_fdsn.app.core.event_exporter.export_events_helpers import exceptions

namespace_regex = re.compile('^{([\w:\-\/\.]+)}([\w]+)$')


def extract_events(quakeml):
    """

    :return:
    """
    parent_qml_meta = xmltodict.parse(quakeml)
    # Returns list if multiple events, else returns an OrderedDict
    return parent_qml_meta['q:quakeml']['eventParameters']['event']


class TestEvent2Qml(unittest.TestCase):

    def setUp(self):
        self.pf_path = os.path.join(os.path.dirname(__file__), os.pardir, 'test_data', 'event2qmltest.pf')

    def test_event2qml_basic(self):
        """

        :return:
        """
        view_db = os.path.join(os.path.dirname(__file__), os.pardir, 'test_data', 'dbe_1101')
        quakeml = event2qml.event2qml(self.pf_path, view_db, event_id=None,
                                      includeallorigins=False)

        self.assertIn('quakeml', quakeml)
        xd = xmltodict.parse(quakeml)
        self.assertIsInstance(xd, collections.OrderedDict)

    def test_event2qml_filter_event_id_all_origins(self):
        """

        :return:
        """
        view_db = os.path.join(os.path.dirname(__file__), os.pardir, 'test_data', 'dbe_1101')
        quakeml = event2qml.event2qml(self.pf_path, view_db, event_id=7,
                                      includeallorigins=True)

        event = extract_events(quakeml)
        # Check if event_id 7 exists in events
        if not event:
            self.assertFalse(True, 'Expecting to find events in test db but none found')

        event_id = int(event['@publicID'].split('/')[-1])

        self.assertEqual(7, event_id)
        # If single origin, it will be an OrdereDict, else a list.
        self.assertIsInstance(event['origin'], list)

    def test_event2qml_test_event_id_preferred_origin(self):
        """Test if requested event ID is returned and only preferred origin

        :return:
        """
        view_db = os.path.join(os.path.dirname(__file__), os.pardir, 'test_data', 'dbe_1101')
        quakeml = event2qml.event2qml(self.pf_path, view_db, event_id=7,
                                      includeallorigins=False)

        event = extract_events(quakeml)

        # Check if event_id 7 exists in events
        if not event:
            self.assertFalse(True, 'Expecting to find events in test db but none found')

        event_id = int(event['@publicID'].split('/')[-1])
        self.assertEqual(7, event_id)
        # If single origin, it will be an OrdereDict, else a list.
        self.assertIsInstance(event['origin'], collections.OrderedDict)
